OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "{version} 釋出了，可以更新",
    "Updater" : "更新者",
    "Update channel:" : "更新通道:",
    "You can always update to a newer version / experimental channel. But you can never downgrade to a more stable channel." : "您可以隨時更新至較新的版本 / 實驗通道，但您不能降版至更穩定的通道。",
    "Update notifications" : "通知更新"
},
"nplurals=1; plural=0;");
